#version 330

layout(location = 0) in vec3 position;
layout(location = 1) in vec3 normal;

out vec3 normalViewSpace;
out vec3 positionViewSpace;
out vec3 lightVectorViewSpace;

uniform mat4 modelMatrix;
uniform mat4 projectionMatrix;
uniform mat4 viewMatrix;

void main()
{
	// make sure to use model with per-vertex normals, not just per-face normals

	vec3 normalN = normalize(normal);
	mat4 modelViewMatrix = viewMatrix * modelMatrix;
	mat4 normalMatrix = transpose(inverse(modelViewMatrix));
	
	normalViewSpace = (normalMatrix * vec4(normalN, 0)).xyz;
	positionViewSpace = (modelViewMatrix * vec4(position, 1)).xyz;

	vec4 lightPos = vec4(200.0, 200.0, 1.0, 1.0);
	vec3 lightPosViewSpace = (modelViewMatrix * lightPos).xyz;
	lightVectorViewSpace = lightPosViewSpace - positionViewSpace;

	gl_Position = projectionMatrix * modelViewMatrix * vec4(position, 1);

}