#version 330

in vec3 normalViewSpace;
in vec3 positionViewSpace;
in vec3 lightVectorViewSpace;

in vec2 fragmentUV;

out vec4 fragColor;

uniform sampler2D colorTexture;

void main() {	
	const float A = 0.2;
	const float B = 0.3;
	const float C = 0.6;
	const float D = 1.0;

	vec3 textureColor = texture(colorTexture, fragmentUV).rgb;

	vec3 normal = normalize(normalViewSpace);

	const float ambient = 0.1;

	vec3 lightVecN = normalize(lightVectorViewSpace);

	// diffuse term could be negative
	float diffuse = dot(normal, lightVecN);
	if (diffuse < A) diffuse = 0.1;
	else if (diffuse < B) diffuse = B;
	else if (diffuse < C) diffuse = C;
	else diffuse = D;
	
	// specular term
	const float shininess = 30.0;
	vec3 viewVector = normalize(-positionViewSpace);
	vec3 reflectedViewVec = reflect(viewVector, normal);
	float specularAmount = max(0.0, dot(lightVecN, -reflectedViewVec));
	specularAmount = pow(specularAmount, shininess);

	specularAmount = step(0.5, specularAmount);

	vec3 specular = specularAmount * vec3(1.0, 1.0, 1.0);

	fragColor = vec4(ambient + diffuse * textureColor + specular, 1.0);
}